class eosclient::autofs () inherits eosclient {

  if $::eosclient::manage_autofs_rpm {
    ensure_packages('autofs')
  }

  $eosmounts = $::eosclient::mounts

  $_autofs_notify = $::eosclient::manage_autofs_service ? {
    true    => 'Service[autofs]',
    default => undef ,
  }

  Package['autofs']
  ->
  # orderly removal of sysvinit versions of eos-fuse
  package { 'eos-fuse':
    ensure => 'absent',
  }
  ->
  package { 'eos-fuse-sysv':
    ensure => 'absent',
  }
  ->
  # set autofs.conf: browse_mode = yes
  ini_setting { 'set autofs browse mode yes':
    ensure  => present,
    path    => '/etc/autofs.conf',
    section => ' autofs ',
    setting => 'browse_mode',
    value   => 'yes',
    notify  => $_autofs_notify,
  }
  ->
  # add line for each instance to auto.eos: <instance> -fstype=eos :user
  file{'/etc/auto.eos':
    content => template('eosclient/auto.eos.erb'),
    mode    => '0644',
    owner   => root,
    group   => root,
    notify  => $_autofs_notify,
  }
  ->
  # add line to auto.master: /eos /etc/auto.eos
  augeas{'eos_automaster':
    context => '/files/etc/auto.master/',
    lens    => 'Automaster.lns',
    incl    => '/etc/auto.master',
    changes => [
      'set 01      /eos',
      'set 01/map  /etc/auto.eos',
    ],
    onlyif  => 'match *[map="/etc/auto.eos"] size == 0',
    notify  => $_autofs_notify,
  }
  if $::eosclient::manage_autofs_service {
    ensure_resource('service','autofs',
      { ensure     => true,
        enable     => true,
        hasrestart => true,
      }
    )
  }
}
