class eosclient::fuse (
$enable_lemon = $eosclient::enable_lemon,
) inherits eosclient {

  # repo set up etc.
  # keep this include until all clients drop the deprecated include eosclient::fuse syntax
  include ::eosclient

  $allmounts = keys(hiera('eosclient_instance_config'))

  $eosmounts = $::eosclient::mounts

  $unmounted = difference($allmounts, $eosmounts)
  eosclient::mount { $unmounted:
    remove => true,
  }

  if empty($eosmounts) {
    err('No mounts specified. Supply an array of mounts via hiera(eos_mounts) or eosclient::fuse::mounts.')
  }

  # get the configuration to be written to /etc/sysconfig/eos
  $eosclient_sysconfig = merge(hiera('eosclient_common_config'), hiera('eosclient_custom_config', {}))

  if $::eosclient::enable_autofs {
    $eospkg = 'eos-fuse-core'
  } else {
    $eospkg = ['eos-fuse', 'eos-fuse-core', 'eos-fuse-sysv']
  }

  if $::eosclient::allow_osrepos {
    Osrepos::Kojitag['eos'] -> Package[$eospkg]
  }

  package{$eospkg:
    ensure  => $::eosclient::version,
  }
  ->
  augeas{'eosfuse_logrotate':
    changes => [
      "set /files/etc/logrotate.d/eos-fuse-logs/rule/rotate ${::eosclient::fuse_logrotate_days}",
    ],
  }
  ->
  file{'/etc/sysconfig/eos':
    content => template('eosclient/sysconfig_eos.erb'),
    mode    => '0444',
    owner   => root,
    group   => root,
  }
  ->
  file{'/eos':
    ensure  => directory,
    mode    => '0755',
    owner   => root,
    group   => root,
    seltype => 'default_t',
  }
  ->
  file{'/var/run/eosd':
    ensure => directory,
    mode   => '0755',
    owner  => root,
    group  => root,
  }
  ->
  file{'/var/run/eosd/credentials':
    ensure => directory,
    mode   => '1777',
    owner  => root,
    group  => root,
  }
  ->
  file{'/var/run/eosd/credentials/store':
    ensure => directory,
    mode   => '1777',
    owner  => root,
    group  => root,
  }
  ->
  file{'/var/log/eos':
    ensure => directory,
    mode   => '0744',
    owner  => daemon,
    group  => daemon,
  }
  ->
  file{'/var/log/eos/fuse':
    ensure => directory,
    mode   => '0744',
    owner  => daemon,
    group  => daemon,
  }
  ->
  eosclient::mount { $eosmounts: }

  file {'/usr/local/sbin/eos-cleanup.sh':
    source => 'puppet:///modules/eosclient/eos-cleanup.sh',
    mode   => '0755',
    owner  => root,
    group  => root,
  } ->
  cron {'eos-cleanup':
    command => '/usr/local/sbin/eos-cleanup.sh',
    minute  => fqdn_rand(60, 'eos-cleanup'),
  }

  if $::eosclient::enable_autofs {

    include ::eosclient::autofs
    Eosclient::Mount[$eosmounts] -> Package['autofs']

  } else {

    service{'eosd':
      ensure    => 'running',
      enable    => true,
      hasstatus => true,
      require   => [ Eosclient::Mount[$eosmounts] ],
    }

    # LEMON using the 'eosd' init script return code (0 = running, 1=dead+locked, 2=stopped)
    if $enable_lemon {
      lemon::metric{'13393':}  # eosd_service
      lemon::metric{'33746':}  # eosd_service_error
    }
  }

  # FIXME: this is a hack to remove the premature systemd scripts that arrived with 4.1.11
  package { 'eos-fuse-sys':
    ensure => 'absent',
  }
}
