define eosclient::mount (
  $remove = false,
) {
  $instance = $name

  if $remove {
    file{"/etc/sysconfig/eos.${instance}":
      ensure => 'absent',
    }
  } else {
    # lookup the common and instance configs
    # these are predefined by this module with useful defaults
    $eosclient_common_config = hiera('eosclient_common_config')
    $eosclient_instance_config = hiera('eosclient_instance_config')

    # lookup the custom config hash.
    # this is where a user may override individual settings
    $eosclient_custom_config = hiera('eosclient_custom_config', {})

    # validate the instance name
    unless has_key($eosclient_instance_config, $instance) {
      err("Unable to configure eosclient for unknown EOS instance: ${instance}")
    }

    # merge the configs. for variables in both hashes, the rightmost hash wins.
    $merged_options = merge($eosclient_common_config, $eosclient_instance_config[$instance], $eosclient_custom_config)

    file{"/etc/sysconfig/eos.${instance}":
      content => template('eosclient/sysconfig_eos_instance.erb'),
      mode    => '0444',
      owner   => root,
      group   => root,
    }

    file{"/var/log/eos/fuse/fuse.${instance}.log":
      ensure => present,
      mode   => '0600',
      owner  => root,
      group  => root,
    }
  }
}
