require 'spec_helper'
describe 'eosclient' do

  context 'with CentOS7' do
    let(:hiera_config) { 'spec/hiera.yaml' }
    let(:facts){{ os:   {'release' => { 'major' => '7' }} ,
                  operatingsystemmajrelease: '7',
                  architecture: 'x86_64',
                  osfamily: 'RedHat',
                  operatingsystem: 'CentOS',
    }}

    context 'enable_lemon false and all others default' do
      it { is_expected.to compile.with_all_deps }
      let(:params){{ enable_lemon: false,
      }}
      it { should contain_class('eosclient') }
      it { should contain_package('eos-client').with_ensure('present') }
      it { is_expected.to have_lemon__metric_resource_count(0) }

    end
    context 'enable_lemon false and with version parameter set' do
      let(:params){{ version: '1.2.3',
                     enable_lemon: false,
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_package('eos-client').with_ensure('1.2.3') }
    end
    context 'enable_lemon false and with enable_fuse parameter set' do
      let(:params){{ enable_fuse: true,
                     enable_lemon: false,
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_package('eos-fuse') }
      it { is_expected.not_to contain_service('autofs') }
    end
    context 'enable_lemon false,  and with enable_fuse parameter set' do
      let(:params){{ enable_fuse: true,
                     enable_lemon: false,
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_package('eos-fuse') }
      it { is_expected.not_to contain_service('autofs') }
    end
    context 'enable_lemon false, enable_autofs,  and with enable_fuse parameter set' do
      let(:params){{ enable_fuse: true,
                     enable_lemon: false,
                     enable_autofs: true
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_package('eos-fuse') }
      it { is_expected.to contain_service('autofs') }
    end
    context 'enable_lemon false, enable_autofs, manage_autofs_service=>false  and with enable_fuse parameter set' do
      let(:params){{ enable_fuse: true,
                     enable_lemon: false,
                     enable_autofs: true,
                     manage_autofs_service: false,
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_package('eos-fuse') }
      it { is_expected.not_to contain_service('autofs') }
    end


    context 'enable_lemon false and with enable_pam_hook parameter set' do
      let(:params){{ enable_pam_hook: true,
                     enable_lemon: false,
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_file('/etc/profile.d/eos-select.sh') }
    end
    context 'enable_lemon false, fuse true and with mounts parameter set' do
      let(:params){{ mounts: ['atlas'],
                     enable_fuse: true,
                     enable_lemon: false,
      }}
      it { is_expected.to compile.with_all_deps }
      it { should contain_file('/etc/sysconfig/eos.atlas') }
    end
  end
end
